// Proto file representing the EDB BundleTerminal class

syntax = "proto3";
package ansys.api.edb.v1;

import "ansys/api/edb/v1/edb_messages.proto";

service BundleTerminalService {
  rpc Create (EDBObjCollectionMessage) returns (EDBObjMessage) {}

  rpc Ungroup (EDBObjMessage) returns (google.protobuf.Empty) {}

  rpc GetTerminals (EDBObjMessage) returns (EDBObjCollectionMessage) {}
  rpc StreamTerminals (EDBObjMessage) returns (stream EDBObjCollectionMessage) {}
}
