// Proto file representing the layout obj instance 2d geometry class

syntax = "proto3";

package ansys.api.edb.v1;

import "ansys/api/edb/v1/edb_messages.proto";
import "ansys/api/edb/v1/point_3d_data.proto";
import "ansys/api/edb/v1/layout_obj_instance_geometry.proto";

service LayoutObjInstance3DGeometryService {
  rpc GetTesselationData(LayoutObjInstanceGeometryMessage) returns (TesselationDataMessage) {}
}

message Triangle3DDataMessage {
  Point3DMessage point_1 = 1;
  Point3DMessage point_2 = 2;
  Point3DMessage point_3 = 3;
}

message TesselationDataMessage {
  repeated Triangle3DDataMessage tesselation_data = 1;
}
