// Proto file representing references to EDB Port Post Processing Prop

syntax = "proto3";

package ansys.api.edb.v1;

import "ansys/api/edb/v1/edb_messages.proto";

message PortPostProcessingPropMessage {
  ValueMessage voltage_magnitude = 1;
  ValueMessage voltage_phase = 2;
  ValueMessage deembed_length = 3;
  ValueMessage renormalization_impedance = 4;
  bool do_deembed = 5;
  bool do_deembed_gap_length = 6;
  bool do_renormalize = 7;
}
