// Proto file representing the layout instance context class

syntax = "proto3";

package ansys.api.edb.v1;

import "ansys/api/edb/v1/edb_messages.proto";
import "ansys/api/edb/v1/point_data.proto";

service LayoutInstanceContextService {
  rpc GetLayout(EDBObjMessage) returns (EDBObjMessage) {}

  rpc GetBBox(BoolPropertyMessage) returns (BoxMessage) {}

  rpc IsTopOrBlackBox(EDBObjMessage) returns (google.protobuf.BoolValue) {}

  rpc GetTopOrBlackBox(EDBObjMessage) returns (EDBObjMessage) {}

  rpc GetPlacementElevation(EDBObjMessage) returns (google.protobuf.DoubleValue) {}

  rpc Is3DPlacement(BoolPropertyMessage) returns (google.protobuf.BoolValue) {}

  rpc GetTransformation(EDBObjMessage) returns (EDBObjMessage) {}

  rpc GetTransformationBetweenContexts(EDBObjPairMessage) returns (EDBObjMessage) {}
}
