// Proto file representing references to EDB Object classes

syntax = "proto3";

package ansys.api.edb.v1;

import "ansys/api/edb/v1/edb_messages.proto";

message LayerRefMessage {
  oneof ref {
    EDBObjMessage id = 1;
    google.protobuf.StringValue name = 2;
  }
}

message LayerRefPropertyMessage {
  EDBObjMessage edb_obj = 1;
  LayerRefMessage layer_ref = 2;
}

message NetRefMessage {
  oneof ref {
    EDBObjMessage id = 1;
    google.protobuf.StringValue name = 2;
  }
}

message CellInstanceRefMessage {
  oneof ref {
    EDBObjMessage id = 1;
    google.protobuf.StringValue name = 2;
  }
}
