// Proto file representing the SParameterModel class

syntax = "proto3";

package ansys.api.edb.v1;

import "ansys/api/edb/v1/edb_messages.proto";

service SParameterModelService {
  rpc Create (SParameterModelMessage) returns (EDBObjMessage) {}

  rpc GetProperties (EDBObjMessage) returns (SParameterModelMessage) {}

  rpc SetComponentModelName (StringPropertyMessage) returns (google.protobuf.Empty) {}
  rpc SetReferenceNet (StringPropertyMessage) returns (google.protobuf.Empty) {}
}

message SParameterModelMessage {
  string name = 1;
  string ref_net = 2;
}
