// Proto file representing the NetlistModel class

syntax = "proto3";

package ansys.api.edb.v1;

import "ansys/api/edb/v1/edb_messages.proto";

service NetlistModelService {
  rpc Create (google.protobuf.StringValue) returns (EDBObjMessage) {}
  rpc GetNetlist (EDBObjMessage) returns (google.protobuf.StringValue) {}
  rpc SetNetlist (StringPropertyMessage) returns (google.protobuf.Empty) {}
}
