// Proto file representing references to EDB Rlc classes

syntax = "proto3";

package ansys.api.edb.v1;

import "ansys/api/edb/v1/edb_messages.proto";
import "ansys/api/edb/v1/refs.proto";

service DifferentialPairService {
  // create a differential pair
  rpc Create (DifferentialPairCreationMessage) returns (EDBObjMessage) {}

  // find a differential pair
  rpc FindByName (StringPropertyMessage) returns (EDBObjMessage) {}

  // differential pair accessors
  rpc GetDifferentialPair (EDBObjMessage) returns (DifferentialPairNetRefsMessage) {}
  rpc SetDifferentialPair (DifferentialPairNetRefsMessage) returns (google.protobuf.Empty) {}
}

message DifferentialPairCreationMessage {
  EDBObjMessage layout = 1;
  string name = 2;
  NetRefMessage positive_net = 3;
  NetRefMessage negative_net = 4;
}

message DifferentialPairNetRefsMessage {
  EDBObjMessage dp = 1;
  NetRefMessage positive_net = 2;
  NetRefMessage negative_net = 3;
}
