// Proto file representing the PinPairModel class

syntax = "proto3";

package ansys.api.edb.v1;

import "ansys/api/edb/v1/edb_messages.proto";
import "ansys/api/edb/v1/rlc.proto";

service PinPairModelService {
  rpc Create (google.protobuf.Empty) returns (EDBObjMessage) {}
  rpc GetRlc (StringPairPropertyMessage) returns (PinPairRlcMessage) {}
  rpc SetRlc (PinPairModelRlcPropertyMessage) returns (google.protobuf.Empty) {}
  rpc DeleteRlc (StringPairPropertyMessage) returns (google.protobuf.Empty) {}
  rpc GetPinPairs (EDBObjMessage) returns (StringPairsMessage) {}
}

message PinPairModelRlcPropertyMessage {
  EDBObjMessage model = 1;
  StringPairMessage pins = 2;
  RlcMessage rlc = 3;
}

message PinPairRlcMessage {
  bool found = 1;
  RlcMessage rlc = 2;
}