// Proto file representing the RLC Component Property class

syntax = "proto3";

// Package
package ansys.api.edb.v1;

// Imports
import "ansys/api/edb/v1/edb_messages.proto";

// RLC Component Property service definition
service RLCComponentPropertyService {
  // Create RLC Component Property
  rpc Create(google.protobuf.Empty) returns (EDBObjMessage) {}

  // Get/Set enabled
  rpc GetEnabled(EDBObjMessage) returns (google.protobuf.BoolValue) {}
  rpc SetEnabled(BoolPropertyMessage) returns (google.protobuf.Empty) {}
}
