// Proto file containing type definitions

syntax = "proto3";

package ansys.api.edb.v1;

enum ProductIdType {
  DESIGNER = 0;
  SI_WAVE = 1;
  GENERIC_TRANSLATOR = 2;
  USER_DEFINED = 3;
  INVALID_PRODUCT = -1;
}

enum DesignMode {
  GENERAL_MODE = 0;
  IC_MODE = 1;
}

enum CellType {
  CIRCUIT_CELL = 0;
  FOOTPRINT_CELL = 1;
}

enum GeometryExtentType {
  BOUNDING_BOX = 0;
  CONFORMING = 1;
}

// Enum for SimulationSetup types
enum SimulationSetupType {
  HFSS_SIM = 0;
  SI_WAVE_SIM = 2;
  SI_WAVE_DCIR_SIM = 9;
  RAPTOR_X_SIM = 12;
}

//------------------------------------------------------------------------------
// Frequency Sweep Type

enum FreqSweepType {
  INTERPOLATING_SWEEP = 0;
  DISCRETE_SWEEP = 1;
  BROADBAND_SWEEP = 2;
}

//------------------------------------------------------------------------------ 
// HFSS Extents

enum HfssExtentsType {
  HFSS_EXTENT_BOUNDING_BOX = 0;
  HFSS_EXTENT_CONFIRMING = 1;
  HFSS_EXTENT_CONVEX_HULL = 2;
  HFSS_EXTENT_POLYGON = 3;
}

enum HfssExtentsOpenRegionType {
  HFSS_EXTENT_RADIATION = 0;
  HFSS_EXTENT_PML = 1;
}

//------------------------------------------------------------------------------ 
// Component

enum ComponentType {
  OTHER = 0;
  RESISTOR = 1;
  INDUCTOR = 2;
  CAPACITOR = 3;
  IC = 4;
  IO = 5;
  INVALID = -1;
}
